import bmt

if __name__ == '__main__':
    bmt.main()
